@@ -1,4 +1,4 @@
-from dfa import DFA
+from dfa import DFA, dict2dfa
 from pyrsistent import pmap
 
 from aiger_dfa import dfa2aig
@@ -26,7 +26,7 @@ def test_dfa2aig():
         is_valid = vout['valid'][0]
 
         out, lout = simulator.send(action_bv)
-        label = relabels['outputs'][pmap(out)]
+        label = relabels['outputs'][pmap({'output': out['prev_output']})]
         return label, is_valid, lout['state']
 
     prev_state = circ.latch2init['state']
@@ -43,9 +43,11 @@ def test_dfa2aig():
 
     # One invalid input should invalidate the run.
 
-    vout, _ = vsimulator.send({'action': (True, True)})
+    vout, _ = vsimulator.send({'action': 0b11})
     assert not vout['valid'][0]
 
     for i in range(5):
         _, valid, _ = step(0)
         assert not valid
+
+
